/**
 * @module createElement
 */


import {createElement as reactCreateElement} from 'react';

import parseArgs from './parseArgs';


/* eslint-disable prefer-rest-params, no-unused-vars */

/**
 * Create a React element using the 0 to 3 additional arguments of a HyperScript call.
 * @param {(string|ReactComponent)} type - HTML tag name or React component.
 * @param {string=} selector - CSS like selector of the form '#myid.class1.class2'.
 * @param {Object=} props - React element props, could be null.
 * @param {...(string|ReactElement)} children - a series of child elements, possibly none.
 * @returns {Object} A tuple [props, children] to pass to React.createElement.
 */
function createElement(type, selector, props, children) {
	const args = Array.prototype.slice.call(arguments, 1);
	const [_props, _children] = parseArgs.apply(null, args);

	return reactCreateElement(type, _props, ..._children);
}


export default createElement;
