/**
 * @module parseArgs
 */


import parseSelector from './parseSelector';


/**
 * Parse the 0 to 3 arguments of a HyperScript call into React element props and children.
 * @param {...any} args - A placeholder for the signiture
 *   (selector?: string, props?: Object, ...children: (string|ReactElement)[])
 * @returns {Object} A tuple [props, children] to pass to React.createElement.
 */
function parseArgs(...args) {
	let argi = 0;
	let arg = args[argi ++];

	let id = undefined;
	let className = undefined;

	if (typeof arg === 'string') {
		const char0 = arg.charAt(0);
		if (char0 === '#' || char0 === '.') {
			[id, className] = parseSelector(arg);
			arg = args[argi ++];
		}
	}

	let props = {};

	if (arg === null) {
		arg = args[argi ++];
	}
	else if (typeof arg === 'object' && arg.$$typeof === undefined) {
		props = arg;
		arg = args[argi ++];
	}

	if (id !== undefined) {
		props.id = id;
	}

	if (className !== undefined) {
		if (props.className !== undefined) {
			props.className = className + ' ' + props.className;
		}
		else {
			props.className = className;
		}
	}

	const children = args.slice(argi - 1);

	return [props, children];
}


export default parseArgs;
