/**
 * @module parseSelector
 */


// support memoization
const resultMemo = new Map();


/**
 * Parse a pseudo-selector into an element id and className string.
 * @param {string} selector The selector to be parsed.
 * @returns {[string, string]} A tuple [id, className], either of which could be undefined.
 */
function parseSelector(selector) {
	if (typeof selector !== 'string') {
		return [undefined, undefined];
	}

	if (resultMemo.has(selector)) {
		return resultMemo.get(selector);
	}

	// split '#foo.bar .baz' into:
	//    ['', '#', 'foo', '', '.', 'bar', ' ', '.', 'baz', '']
	const tokenList = selector.split(/([\.#])([a-zA-Z0-9\u007F-\uFFFF_:-]+)/);

	let id = undefined;
	const classList = [];

	for (let i = 1; i < tokenList.length - 1; i += 3) {
		if (tokenList[i] === '#') {
			id = tokenList[i + 1];
		}
		if (tokenList[i] === '.') {
			classList.push(tokenList[i + 1]);
		}
	}

	let className = undefined;

	if (classList.length !== 0) {
		className = classList.join(' ');
	}

	const result = [id, className];

	// resultMemo.set(selector, result);

	return result;
}


export default parseSelector;
